@@ -1,10 +1,10 @@
 import logging
 import random
 
-from avocado.core.output import LOG_UI, Throbber
+from avocado_varianter_cit.CombinationMatrix import CombinationMatrix
+from avocado_varianter_cit.Solver import Solver
 
-from .CombinationMatrix import CombinationMatrix
-from .Solver import Solver
+from avocado.core.output import LOG_UI, Throbber
 
 ITERATIONS_SIZE = 600
 LOG = LOG_UI.getChild("Cit")
@@ -311,7 +311,7 @@ class Cit:
         data_size = len(self.data)
         row = [-1]*data_size
 
-        for parameter in random.sample(range(data_size), data_size):  # pylint: disable=W1638
+        for parameter in random.sample(range(data_size), data_size):
             possible_values = self.solver.get_possible_values(row, parameter)
             value_choice = random.choice(possible_values)
             row[parameter] = value_choice
